@@ -28,7 +28,7 @@ and user errors in SCons.
 
 """
 
-__revision__ = "src/engine/SCons/Errors.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
+__revision__ = "src/engine/SCons/Errors.py 72ae09dc35ac2626f8ff711d8c4b30b6138e08e3 2019-08-08 14:50:06 bdeegan"
 
 import shutil
 import SCons.Util
@@ -124,7 +124,7 @@ class UserError(Exception):
 class StopError(Exception):
     pass
 
-class EnvironmentError(Exception):
+class SConsEnvironmentError(Exception):
     pass
 
 class MSVCError(IOError):
@@ -184,7 +184,7 @@ def convert_to_BuildError(status, exc_info=None):
             filename=filename,
             exc_info=exc_info)
 
-    elif isinstance(status, (EnvironmentError, OSError, IOError)):
+    elif isinstance(status, (SConsEnvironmentError, OSError, IOError)):
         # If an IOError/OSError happens, raise a BuildError.
         # Report the name of the file or directory that caused the
         # error, which might be different from the target being built
