@@ -12,7 +12,7 @@ libraries are installed, if some command line options are supported etc.
 """
 
 #
-# Copyright (c) 2001 - 2015 The SCons Foundation
+# Copyright (c) 2001 - 2019 The SCons Foundation
 #
 # Permission is hereby granted, free of charge, to any person obtaining
 # a copy of this software and associated documentation files (the
@@ -33,8 +33,9 @@ libraries are installed, if some command line options are supported etc.
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
+from __future__ import print_function
 
-__revision__ = "src/engine/SCons/SConf.py rel_2.4.1:3453:73fefd3ea0b0 2015/11/09 03:25:05 bdbaddog"
+__revision__ = "src/engine/SCons/SConf.py 72ae09dc35ac2626f8ff711d8c4b30b6138e08e3 2019-08-08 14:50:06 bdeegan"
 
 import SCons.compat
 
@@ -109,7 +110,7 @@ def _createConfigH(target, source, env):
 #define %(DEFNAME)s_SEEN
 
 """ % {'DEFNAME' : defname})
-    t.write(source[0].get_contents())
+    t.write(source[0].get_contents().decode())
     t.write("""
 #endif /* %(DEFNAME)s_SEEN */
 """ % {'DEFNAME' : defname})
@@ -131,10 +132,10 @@ def CreateConfigHBuilder(env):
                                  _stringConfigH)
     sconfigHBld = SCons.Builder.Builder(action=action)
     env.Append( BUILDERS={'SConfigHBuilder':sconfigHBld} )
-    for k in _ac_config_hs.keys():
+    for k in list(_ac_config_hs.keys()):
         env.SConfigHBuilder(k, env.Value(_ac_config_hs[k]))
 
-    
+
 class SConfWarning(SCons.Warnings.Warning):
     pass
 SCons.Warnings.enableWarningClass(SConfWarning)
@@ -163,11 +164,11 @@ class ConfigureCacheError(SConfError):
 # define actions for building text files
 def _createSource( target, source, env ):
     fd = open(str(target[0]), "w")
-    fd.write(source[0].get_contents())
+    fd.write(source[0].get_contents().decode())
     fd.close()
 def _stringSource( target, source, env ):
     return (str(target[0]) + ' <-\n  |' +
-            source[0].get_contents().replace( '\n', "\n  |" ) )
+            source[0].get_contents().decode().replace( '\n', "\n  |" ) )
 
 class SConfBuildInfo(SCons.Node.FS.FileBuildInfo):
     """
@@ -176,7 +177,7 @@ class SConfBuildInfo(SCons.Node.FS.FileBuildInfo):
     contains messages of the original build phase.
     """
     __slots__ = ('result', 'string')
-    
+
     def __init__(self):
         self.result = None # -> 0/None -> no error, != 0 error
         self.string = None # the stdout / stderr output when building the target
@@ -217,7 +218,7 @@ class Streamer(object):
         if self.orig:
             self.orig.flush()
         self.s.flush()
-        
+
 
 class SConfBuildTask(SCons.Taskmaster.AlwaysTask):
     """
@@ -245,6 +246,7 @@ class SConfBuildTask(SCons.Taskmaster.AlwaysTask):
         # ConfigureCacheError and if yes, reraise the exception
         exc_type = self.exc_info()[0]
         if issubclass(exc_type, SConfError):
+            # TODO pylint E0704: bare raise not inside except
             raise
         elif issubclass(exc_type, SCons.Errors.BuildError):
             # we ignore Build Errors (occurs, when a test doesn't pass)
@@ -254,14 +256,7 @@ class SConfBuildTask(SCons.Taskmaster.AlwaysTask):
         else:
             self.display('Caught exception while building "%s":\n' %
                          self.targets[0])
-            try:
-                excepthook = sys.excepthook
-            except AttributeError:
-                # Earlier versions of Python don't have sys.excepthook...
-                def excepthook(type, value, tb):
-                    traceback.print_tb(tb)
-                    print type, value
-            excepthook(*self.exc_info())
+            sys.excepthook(*self.exc_info())
         return SCons.Taskmaster.Task.failed(self)
 
     def collect_node_states(self):
@@ -318,7 +313,7 @@ class SConfBuildTask(SCons.Taskmaster.AlwaysTask):
             binfo = self.targets[0].get_stored_info().binfo
             self.display_cached_string(binfo)
             raise SCons.Errors.BuildError # will be 'caught' in self.failed
-        elif is_up_to_date:            
+        elif is_up_to_date:
             self.display("\"%s\" is up to date." % str(self.targets[0]))
             binfo = self.targets[0].get_stored_info().binfo
             self.display_cached_string(binfo)
@@ -329,18 +324,6 @@ class SConfBuildTask(SCons.Taskmaster.AlwaysTask):
             s = sys.stdout = sys.stderr = Streamer(sys.stdout)
             try:
                 env = self.targets[0].get_build_env()
-                if cache_mode == FORCE:
-                    # Set up the Decider() to force rebuilds by saying
-                    # that every source has changed.  Note that we still
-                    # call the environment's underlying source decider so
-                    # that the correct .sconsign info will get calculated
-                    # and keep the build state consistent.
-                    def force_build(dependency, target, prev_ni,
-                                    env_decider=env.decide_source):
-                        env_decider(dependency, target, prev_ni)
-                        return True
-                    if env.decide_source.func_code is not force_build.func_code:
-                        env.Decider(force_build)
                 env['PSTDOUT'] = env['PSTDERR'] = s
                 try:
                     sconf.cached = 0
@@ -353,10 +336,8 @@ class SConfBuildTask(SCons.Taskmaster.AlwaysTask):
             except SystemExit:
                 exc_value = sys.exc_info()[1]
                 raise SCons.Errors.ExplicitExit(self.targets[0],exc_value.code)
-            except Exception, e:
+            except Exception as e:
                 for t in self.targets:
-                    #binfo = t.get_binfo()
-                    #binfo.__class__ = SConfBuildInfo
                     binfo = SConfBuildInfo()
                     binfo.merge(t.get_binfo())
                     binfo.set_build_result(1, s.getvalue())
@@ -375,8 +356,6 @@ class SConfBuildTask(SCons.Taskmaster.AlwaysTask):
                 raise e
             else:
                 for t in self.targets:
-                    #binfo = t.get_binfo()
-                    #binfo.__class__ = SConfBuildInfo
                     binfo = SConfBuildInfo()
                     binfo.merge(t.get_binfo())
                     binfo.set_build_result(0, s.getvalue())
@@ -399,28 +378,56 @@ class SConfBase(object):
     tests, be sure to call the Finish() method, which returns the modified
     environment.
     Some words about caching: In most cases, it is not necessary to cache
-    Test results explicitely. Instead, we use the scons dependency checking
+    Test results explicitly. Instead, we use the scons dependency checking
     mechanism. For example, if one wants to compile a test program
     (SConf.TryLink), the compiler is only called, if the program dependencies
     have changed. However, if the program could not be compiled in a former
-    SConf run, we need to explicitely cache this error.
+    SConf run, we need to explicitly cache this error.
     """
 
     def __init__(self, env, custom_tests = {}, conf_dir='$CONFIGUREDIR',
-                 log_file='$CONFIGURELOG', config_h = None, _depth = 0): 
-        """Constructor. Pass additional tests in the custom_tests-dictinary,
+                 log_file='$CONFIGURELOG', config_h = None, _depth = 0):
+        """Constructor. Pass additional tests in the custom_tests-dictionary,
         e.g. custom_tests={'CheckPrivate':MyPrivateTest}, where MyPrivateTest
         defines a custom test.
         Note also the conf_dir and log_file arguments (you may want to
         build tests in the VariantDir, not in the SourceDir)
         """
         global SConfFS
+
+        # Now create isolated override so setting source_decider doesn't affect parent Environment
+        if cache_mode == FORCE:
+            self.original_env = env
+            self.env = env.Clone()
+
+            # Set up the Decider() to force rebuilds by saying
+            # that every source has changed.  Note that we still
+            # call the environment's underlying source decider so
+            # that the correct .sconsign info will get calculated
+            # and keep the build state consistent.
+            def force_build(dependency, target, prev_ni,
+                            repo_node=None,
+                            env_decider=env.decide_source):
+                try:
+                    env_decider(dependency, target, prev_ni, repo_node)
+                except Exception as e:
+                    raise e
+                return True
+
+            if self.env.decide_source.__code__ is not force_build.__code__:
+                self.env.Decider(force_build)
+
+        else:
+            self.env = env
+
+        # print("Override env:%s"%env)
+
         if not SConfFS:
             SConfFS = SCons.Node.FS.default_fs or \
                       SCons.Node.FS.FS(env.fs.pathTop)
         if sconf_global is not None:
             raise SCons.Errors.UserError
-        self.env = env
+
         if log_file is not None:
             log_file = SConfFS.File(env.subst(log_file))
         self.logfile = log_file
@@ -459,6 +466,7 @@ class SConfBase(object):
                 env = sconf.Finish()
         """
         self._shutdown()
+
         return self.env
 
     def Define(self, name, value = None, comment = None):
@@ -468,10 +476,10 @@ class SConfBase(object):
 
         If value is None (default), then #define name is written. If value is not
         none, then #define name value is written.
-        
-        comment is a string which will be put as a C comment in the
-        header, to explain the meaning of the value (appropriate C comments /* and
-        */ will be put automatically."""
+
+        comment is a string which will be put as a C comment in the header, to explain the meaning of the value
+        (appropriate C comments will be added automatically).
+        """
         lines = []
         if comment:
             comment_str = "/* %s */" % comment
@@ -513,6 +521,20 @@ class SConfBase(object):
                 n.attributes = SCons.Node.Node.Attrs()
             n.attributes.keep_targetinfo = 1
 
+            if True:
+                # Some checkers have intermediate files (for example anything that compiles a c file into a program to run
+                # Those files need to be set to not release their target info, otherwise taskmaster will throw a
+                # Nonetype not callable
+                for c in n.children(scan=False):
+                    # Keep debug code here.
+                    # print("Checking [%s] for builders and then setting keep_targetinfo"%c)
+                    if  c.has_builder():
+                        n.store_info = 0
+                        if not hasattr(c, 'attributes'):
+                            c.attributes = SCons.Node.Node.Attrs()
+                        c.attributes.keep_targetinfo = 1
+                    # pass
+
         ret = 1
 
         try:
@@ -619,7 +641,7 @@ class SConfBase(object):
         ok = self.TryBuild(self.env.SConfActionBuilder, text, extension)
         del self.env['BUILDERS']['SConfActionBuilder']
         if ok:
-            outputStr = self.lastTarget.get_contents()
+            outputStr = self.lastTarget.get_text_contents()
             return (1, outputStr)
         return (0, "")
 
@@ -653,7 +675,7 @@ class SConfBase(object):
             node = self.env.Command(output, prog, [ [ pname, ">", "${TARGET}"] ])
             ok = self.BuildNodes(node)
             if ok:
-                outputStr = output.get_contents()
+                outputStr = SCons.Util.to_str(output.get_contents())
                 return( 1, outputStr)
         return (0, "")
 
@@ -681,7 +703,7 @@ class SConfBase(object):
         """Adds all the tests given in the tests dictionary to this SConf
         instance
         """
-        for name in tests.keys():
+        for name in list(tests.keys()):
             self.AddTest(name, tests[name])
 
     def _createDir( self, node ):
@@ -700,7 +722,7 @@ class SConfBase(object):
         global _ac_config_logs
         global sconf_global
         global SConfFS
-        
+
         self.lastEnvFs = self.env.fs
         self.env.fs = SConfFS
         self._createDir(self.confdir)
@@ -727,7 +749,7 @@ class SConfBase(object):
             self.logstream.write('file %s,line %d:\n\tConfigure(confdir = %s)\n' %
                                  (tb[0], tb[1], str(self.confdir)) )
             SConfFS.chdir(old_fs_dir)
-        else: 
+        else:
             self.logstream = None
         # we use a special builder to create source files from TEXT
         action = SCons.Action.Action(_createSource,
@@ -749,13 +771,21 @@ class SConfBase(object):
             self.logstream.write("\n")
             self.logstream.close()
             self.logstream = None
-        # remove the SConfSourceBuilder from the environment
-        blds = self.env['BUILDERS']
-        del blds['SConfSourceBuilder']
-        self.env.Replace( BUILDERS=blds )
+
+        # Now reset the decider if we changed it due to --config=force
+        # We saved original Environment passed in and cloned it to isolate
+        # it from being changed.
+        if cache_mode == FORCE:
+            self.env.Decider(self.original_env.decide_source)
+
+            # remove the SConfSourceBuilder from the environment
+            blds = self.env['BUILDERS']
+            del blds['SConfSourceBuilder']
+            self.env.Replace( BUILDERS=blds )
+
         self.active = 0
         sconf_global = None
-        if not self.config_h is None:
+        if self.config_h is not None:
             _ac_config_hs[self.config_h] = self.config_h_text
         self.env.fs = self.lastEnvFs
 
@@ -766,10 +796,10 @@ class CheckContext(object):
     A typical test is just a callable with an instance of CheckContext as
     first argument:
 
-    def CheckCustom(context, ...)
-    context.Message('Checking my weird test ... ')
-    ret = myWeirdTestFunction(...)
-    context.Result(ret)
+        def CheckCustom(context, ...):
+            context.Message('Checking my weird test ... ')
+            ret = myWeirdTestFunction(...)
+            context.Result(ret)
 
     Often, myWeirdTestFunction will be one of
     context.TryCompile/context.TryLink/context.TryRun. The results of
@@ -924,14 +954,14 @@ def CheckType(context, type_name, includes = "", language = None):
 
 def CheckTypeSize(context, type_name, includes = "", language = None, expect = None):
     res = SCons.Conftest.CheckTypeSize(context, type_name,
-                                       header = includes, language = language, 
+                                       header = includes, language = language,
                                        expect = expect)
     context.did_show_result = 1
     return res
 
 def CheckDeclaration(context, declaration, includes = "", language = None):
     res = SCons.Conftest.CheckDeclaration(context, declaration,
-                                          includes = includes, 
+                                          includes = includes,
                                           language = language)
     context.did_show_result = 1
     return not res
@@ -1010,12 +1040,12 @@ def CheckLib(context, library = None, symbol = "main",
     compiles without flags.
     """
 
-    if library == []:
+    if not library:
         library = [None]
 
     if not SCons.Util.is_List(library):
         library = [library]
-    
+
     # ToDo: accept path for the library
     res = SCons.Conftest.CheckLib(context, library, symbol, header = header,
                                         language = language, autoadd = autoadd)
