@@ -27,7 +27,7 @@ The Scanner package for the SCons software construction utility.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Scanner/__init__.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
+__revision__ = "src/engine/SCons/Scanner/__init__.py 72ae09dc35ac2626f8ff711d8c4b30b6138e08e3 2019-08-08 14:50:06 bdeegan"
 
 import re
 
@@ -207,7 +207,7 @@ class Base(object):
 
         self = self.select(node)
 
-        if not self.argument is _null:
+        if self.argument is not _null:
             node_list = self.function(node, env, path, self.argument)
         else:
             node_list = self.function(node, env, path)
