@@ -38,7 +38,7 @@ deprecated_python_version = (2, 7, 0)
 # OF CONTRACT, TORT OR OTHERWISE, ARISING FROM, OUT OF OR IN CONNECTION
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 
-__revision__ = "src/engine/SCons/Script/Main.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
+__revision__ = "src/engine/SCons/Script/Main.py 72ae09dc35ac2626f8ff711d8c4b30b6138e08e3 2019-08-08 14:50:06 bdeegan"
 
 
 import SCons.compat
@@ -68,6 +68,20 @@ import SCons.Warnings
 
 import SCons.Script.Interactive
 
+# Global variables
+first_command_start = None
+last_command_end = None
+print_objects = 0
+print_memoizer = 0
+print_stacktrace = 0
+print_time = 0
+sconscript_time = 0
+cumulative_command_time = 0
+exit_status = 0   # final exit status, assume success by default
+this_build_status = 0   # "exit status" of an individual build
+num_jobs = None
+delayed_warnings = []
+
 
 def fetch_win32_parallel_msg():
     # A subsidiary function that exists solely to isolate this import
@@ -87,15 +101,14 @@ def revert_io():
     sys.stderr = sys.__stderr__
     sys.stdout = sys.__stdout__
 
+
 class SConsPrintHelpException(Exception):
     pass
 
+
 display = SCons.Util.display
 progress_display = SCons.Util.DisplayEngine()
 
-first_command_start = None
-last_command_end = None
-
 
 class Progressor(object):
     prev = ''
@@ -443,19 +456,6 @@ def python_version_deprecated(version=sys.version_info):
     return version < deprecated_python_version
 
 
-# Global variables
-
-print_objects = 0
-print_memoizer = 0
-print_stacktrace = 0
-print_time = 0
-sconscript_time = 0
-cumulative_command_time = 0
-exit_status = 0 # final exit status, assume success by default
-this_build_status = 0 # "exit status" of an individual build
-num_jobs = None
-delayed_warnings = []
-
 class FakeOptionParser(object):
     """
     A do-nothing option parser, used for the initial OptionsParser variable.
@@ -1170,7 +1170,7 @@ def _build_targets(fs, options, targets, target_top):
                 # -U, local SConscript Default() targets
                 target_top = fs.Dir(target_top)
                 def check_dir(x, target_top=target_top):
-                    if hasattr(x, 'cwd') and not x.cwd is None:
+                    if hasattr(x, 'cwd') and x.cwd is not None:
                         cwd = x.cwd.srcnode()
                         return cwd == target_top
                     else:
@@ -1376,7 +1376,7 @@ def main():
             revert_io()
     except SystemExit as s:
         if s:
-            exit_status = s
+            exit_status = s.code
     except KeyboardInterrupt:
         print("scons: Build interrupted.")
         sys.exit(2)
