@@ -27,10 +27,10 @@ import sys
 __doc__ = """
     Generic Taskmaster module for the SCons build engine.
     =====================================================
-    
+
     This module contains the primary interface(s) between a wrapping user
     interface and the SCons build engine.  There are two key classes here:
-    
+
     Taskmaster
     ----------
         This is the main engine for walking the dependency graph and
@@ -54,7 +54,7 @@ __doc__ = """
         target(s) that it decides need to be evaluated and/or built.
 """
 
-__revision__ = "src/engine/SCons/Taskmaster.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
+__revision__ = "src/engine/SCons/Taskmaster.py 72ae09dc35ac2626f8ff711d8c4b30b6138e08e3 2019-08-08 14:50:06 bdeegan"
 
 from itertools import chain
 import operator
@@ -477,7 +477,7 @@ class Task(object):
                 for s in t.side_effects:
                     if s.get_state() == NODE_EXECUTING:
                         s.set_state(NODE_NO_STATE)
-                        
+
                     # The side-effects may have been transferred to
                     # NODE_NO_STATE by executed_with{,out}_callbacks, but was
                     # not taken out of the waiting parents/pending children
@@ -551,7 +551,7 @@ class Task(object):
         try:
             exc_type, exc_value, exc_traceback = exc
         except ValueError:
-            exc_type, exc_value = exc
+            exc_type, exc_value = exc  # pylint: disable=unbalanced-tuple-unpacking
             exc_traceback = None
 
         # raise exc_type(exc_value).with_traceback(exc_traceback)
