@@ -33,7 +33,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-# __revision__ = "src/engine/SCons/Tool/clang.py 27552f9e8d59c13c3567f2bd380b74e34ee25324 2019-01-08 02:59:02 bdbaddog"
+# __revision__ = "src/engine/SCons/Tool/clang.py 72ae09dc35ac2626f8ff711d8c4b30b6138e08e3 2019-08-08 14:50:06 bdeegan"
 
 # Based on SCons/Tool/gcc.py by Paweł Tomulik 2014 as a separate tool.
 # Brought into the SCons mainline by Russel Winder 2017.
@@ -77,7 +77,8 @@ def generate(env):
                                      stdout=subprocess.PIPE)
         if pipe.wait() != 0: return
         # clang -dumpversion is of no use
-        line = pipe.stdout.readline()
+        with pipe.stdout:
+            line = pipe.stdout.readline()
         if sys.version_info[0] > 2:
             line = line.decode()
         match = re.search(r'clang +version +([0-9]+(?:\.[0-9]+)+)', line)
