@@ -31,7 +31,7 @@ selection method.
 # WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE SOFTWARE.
 #
 
-__revision__ = "src/engine/SCons/Tool/javah.py 3a41ed6b288cee8d085373ad7fa02894e1903864 2019-01-23 17:30:35 bdeegan"
+__revision__ = "src/engine/SCons/Tool/javah.py 72ae09dc35ac2626f8ff711d8c4b30b6138e08e3 2019-08-08 14:50:06 bdeegan"
 
 import os.path
 
@@ -123,9 +123,9 @@ def generate(env):
     java_javah.emitter = emit_java_headers
 
     if env['PLATFORM'] == 'win32':
-        # Ensure that we have a proper path for clang
-        javah = SCons.Tool.find_program_path(env, 'javah',
-                                             default_paths=get_java_install_dirs(env['PLATFORM']))
+        # Ensure that we have a proper path for javah
+        paths = get_java_install_dirs('win32')
+        javah = SCons.Tool.find_program_path(env, 'javah', default_paths=paths)
         if javah:
             javah_bin_dir = os.path.dirname(javah)
             env.AppendENVPath('PATH', javah_bin_dir)
